@@ -83,6 +83,16 @@ AMBIGUOUS_EXCEPTIONS = {
     'won': 'win',
 }
 
+BRACKET_DIC = {
+    # Turn brackets into what the treebank expects.
+    '(': '-LRB-',
+    ')': '-RRB-',
+    '[': '-LSB-',
+    ']': '-RSB-',
+    '{': '-LCB-',
+    '}': '-RCB-'
+}
+
 def _word_badness(word):
     """
     Assign a heuristic to possible outputs from Morphy. Minimizing this
@@ -161,6 +171,8 @@ def tag_and_stem(text):
     for token, tag in tagged:
         if token.startswith('#'):
             out.append((token, 'TAG', token))
+        elif token in BRACKET_DIC:
+            out.append((token, BRACKET_DIC[token], token))
         else:
             stem = morphy_stem(token, tag)
             out.append((stem, tag, token))
@@ -172,12 +184,20 @@ def good_lemma(lemma):
 def normalize_list(text):
     """
     Get a list of word stems that appear in the text. Stopwords and an initial
-    'to' will be stripped.
+    'to' will be stripped, unless this leaves nothing in the stem.
+
+    >>> normalize_list('the dog')
+    [u'dog']
+    >>> normalize_list('big dogs')
+    [u'big', u'dog']
+    >>> normalize_list('the')
+    [u'the']
     """
+    text = preprocess_text(text)
     pieces = [morphy_stem(word) for word in tokenize_list(text)]
     pieces = [piece for piece in pieces if good_lemma(piece)]
     if not pieces:
-        return text
+        return [text]
     if pieces[0] == 'to':
         pieces = pieces[1:]
     return pieces
@@ -204,7 +224,8 @@ def normalize_topic(topic):
     if not match:
         return normalize(topic), None
     else:
-        return normalize(match.group(1)), 'n/'+match.group(2).strip(' _')
+        return normalize(match.group(1)), 'n/' + match.group(2).strip(' _')
+
 
 def word_frequency(word, default_freq=0):
     """
@@ -222,20 +243,29 @@ def word_frequency(word, default_freq=0):
     - They appear at least 1000 times in Google Books OR
       (they appear at least 40 times in Google Books and also appear in
       Wiktionary or WordNet)
-    
+
     Apostrophes are assumed to be at the edge of the word,
     in which case they'll be stripped like they were in the Google data, or
     in the special token "n't" which is treated as "not". This matches the
     output of the tokenize() function.
+
+    >>> word_frequency('normalization')
+    223058.0
+
+    >>> word_frequency('budap', default_freq=100.)
+    100.0
     """
     freqs = Wordlist.load('google-unigrams.txt')
     if " " in word:
-        raise ValueError("word_frequency only can only look up single words, but %r contains a space" % word)
-    word = preprocess_text(word.strip("'")).upper()
-    if word == "N'T":
-        word = 'NOT'
+        raise ValueError("word_frequency only can only look up single words, "
+                         "but %r contains a space" % word)
+    word = preprocess_text(word.strip("'")).lower()
+    if word == "n't":
+        word = 'not'
     return freqs.get(word, default_freq)
 
+def get_wordlist():
+    return Wordlist.load('google-unigrams.txt')
+
 if __name__ == '__main__':
     print normalize("this is a test")
-
